@@ -1,11 +1,14 @@
 """
 Copyright (c) 2008-2021 synodriver <synodriver@gmail.com>
 """
-from bz3.backends.cython._bz3_cy import (
+from bz3.backends.cython._bz3 import (
     BZ3Compressor,
     BZ3Decompressor,
+    bound,
     compress_file,
-    crc32,
+    compress_into,
     decompress_file,
+    decompress_into,
+    libversion,
     test_file,
 )
