@@ -1,13 +1,16 @@
 """
 Copyright (c) 2008-2021 synodriver <synodriver@gmail.com>
 """
+import sys
+
+sys.path.append(".")
 import os
+from random import randint
 from unittest import TestCase
 
-from bz3 import compress_file, decompress_file
+from bz3 import bound, compress_file, compress_into, decompress_file, decompress_into
 from bz3 import open as bz3_open
-from bz3 import test_file
-
+from bz3 import test_file, libversion
 
 # os.environ["BZ3_USE_CFFI"] = "1"
 
@@ -27,6 +30,18 @@ class TestCompress(TestCase):
         with bz3_open("test.bz3", "rt", encoding="utf-8") as f:
             self.assertEqual(f.read(), "test data")
 
+    def test_zerocopy(self):
+        outsize = bound(100)
+        out = bytearray(200)
+        out2 = bytearray(200)
+        for i in range(1000):
+            inp = bytes([randint(0, 255) for _ in range(100)])
+            buffer_updated = compress_into(inp, out)
+            buffer_updated = decompress_into(out[:buffer_updated], out2)
+            self.assertEqual(bytes(out2[:buffer_updated]), inp)
+
+    def test_version(self):
+        self.assertTrue(isinstance(libversion(), str))
 
 if __name__ == "__main__":
     import unittest
